==> 1.2.0.tar.gz: lib/src/routing/app_route_activity.dart <==
part of 'app_route.dart';

class ActivityRoute<T> extends AppRoute<T> {
  final RouteKeyBuilder? key;
  final RouteTitleBuilder? title;
  final String? restorationId;
  final Set<String> queryParameters;
  final bool maintainState;
  final bool fullscreenDialog;
  final SystemUiStyleBuilder systemUiStyle;
  final RouteWidgetBuilder builder;

  const ActivityRoute({
    this.key,
    this.title,
    this.restorationId,
    required String location,
    this.queryParameters = const {},
    this.maintainState = true,
    this.fullscreenDialog = false,
    this.systemUiStyle = defaultSystemUiStyle,
    required this.builder,
  }) : super._(location: location);

  @override
  Future<T> open(BuildContext context, {RouteArgs args = const {}}) =>
      AppRouterDelegate.of(context).push(this, args: args);

  @factory
  AppPage<T> createPage({RouteArgs args = const {}}) => AppPage._(route: this, args: RouteArgs.from(args));
}

class AppPage<T> extends Page {
  final Completer<T> _result = Completer();

  final ActivityRoute<T> route;

  Future<T> get result => _result.future;

  bool get finished => _result.isCompleted;

  final List<Uri?> _location = [null];

  Uri get location => _location[0] ??= Uri.parse(route.location);

  @override
  RouteArgs get arguments => RouteArgs.unmodifiable(super.arguments as RouteArgs);

  AppPage._({required this.route, required RouteArgs args})
      : super(
            key: route.key?.call(args),
            name: route.title?.call(args),
            arguments: args,
            restorationId: route.restorationId);

  Uri _parametrizedUri([RouteArgs? args]) {
    final parameters = Map<String, String?>.fromEntries((args ?? super.arguments as RouteArgs)
        .entries
        .where((entry) => entry.value != null && route.queryParameters.contains(entry.key))
        .map((entry) => MapEntry(entry.key, entry.value as String)));
    return parameters.isEmpty ? location : location.replace(queryParameters: parameters);
  }

  void updateQueryParameters(RouteArgs params) {
    final uri = _parametrizedUri((super.arguments as RouteArgs)..addAll(params));
    updateUrl(uri);
  }

  @override
  Route<T> createRoute(BuildContext context) => MaterialPageRoute(
      builder: (context) =>
          AnnotatedSystemUIStyle(style: route.systemUiStyle(context), child: route.builder(context, arguments)),
      settings: this,
      maintainState: route.maintainState,
      fullscreenDialog: route.fullscreenDialog)
    ..popped.then(_result.complete, onError: _result.completeError);

  @override
  String toString() => '$runtimeType(${route.location})';

  @optionalTypeArgs
  static AppPage<T> of<T>(BuildContext context) => AppRouterDelegate.of(context).currentConfiguration as AppPage<T>;
}

==> 1.2.1.tar.gz: lib/src/routing/app_route_activity.dart <==
part of 'app_route.dart';

class ActivityRoute<T> extends AppRoute<T> {
  final RouteKeyBuilder? key;
  final RouteTitleBuilder? title;
  final String? restorationId;
  final Set<String> queryParameters;
  final bool maintainState;
  final bool fullscreenDialog;
  final SystemUiStyleBuilder systemUiStyle;
  final RouteWidgetBuilder builder;

  const ActivityRoute({
    this.key,
    this.title,
    this.restorationId,
    required String location,
    this.queryParameters = const {},
    this.maintainState = true,
    this.fullscreenDialog = false,
    this.systemUiStyle = defaultSystemUiStyle,
    required this.builder,
  }) : super._(location: location);

  @override
  Future<T> open(BuildContext context, {RouteArgs args = const {}}) =>
      AppRouterDelegate.of(context).push(this, args: args);

  @factory
  AppPage<T> _createPage({RouteArgs args = const {}}) => AppPage._(route: this, args: RouteArgs.from(args));
}

class AppPage<T> extends Page {
  final Completer<T> _result = Completer();

  final ActivityRoute<T> route;

  Future<T> get result => _result.future;

  bool get finished => _result.isCompleted;

  final List<Uri?> _location = [null];

  Uri get location => _location[0] ??= Uri.parse(route.location);

  @override
  RouteArgs get arguments => RouteArgs.unmodifiable(super.arguments as RouteArgs);

  AppPage._({required this.route, required RouteArgs args})
      : super(
            key: route.key?.call(args),
            name: route.title?.call(args),
            arguments: args,
            restorationId: route.restorationId);

  Uri _parametrizedUri([RouteArgs? args]) {
    final parameters = Map<String, String?>.fromEntries((args ?? super.arguments as RouteArgs)
        .entries
        .where((entry) => entry.value != null && route.queryParameters.contains(entry.key))
        .map((entry) => MapEntry(entry.key, entry.value as String)));
    return parameters.isEmpty ? location : location.replace(queryParameters: parameters);
  }

  void updateQueryParameters(RouteArgs params) {
    final uri = _parametrizedUri((super.arguments as RouteArgs)..addAll(params));
    updateUrl(uri);
  }

  @override
  Route<T> createRoute(BuildContext context) => MaterialPageRoute(
      builder: (context) =>
          AnnotatedSystemUIStyle(style: route.systemUiStyle(context), child: route.builder(context, arguments)),
      settings: this,
      maintainState: route.maintainState,
      fullscreenDialog: route.fullscreenDialog)
    ..popped.then(_result.complete, onError: _result.completeError);

  @override
  String toString() => '$runtimeType(${route.location})';

  @optionalTypeArgs
  static AppPage<T> of<T>(BuildContext context) => AppRouterDelegate.of(context).currentConfiguration as AppPage<T>;
}
